require 'spec_helper'

module Wicoris::Postman
  describe Postman do
    let(:postman) { Postman.new }

    describe '#run' do
      let(:job) { double('job') }

      it 'processes each job' do
        postman.should_receive(:jobs).
          and_return [job, job]
        job.should_receive(:process).twice
        job.should_receive(:clear!).twice
        postman.run
      end

      it 'clears failed jobs too' do
        postman.stub(:jobs).and_return [job]
        job.stub(:process)
        job.should_receive(:clear!)
        postman.run
      end

      context 'when job raises an error' do
        it 'rescues failed jobs' do
          postman.stub(:jobs).and_return [job, job]
          job.should_receive(:process).twice.and_return { raise 'BOOOM!' }
          job.stub(:clear!)
          postman.run
        end

        it 'clears failed jobs too' do
          postman.stub(:jobs).and_return [job]
          job.stub(:process).and_return { raise 'BOOOM!' }
          job.should_receive(:clear!)
          postman.run
        end
      end
    end

    describe '#jobs' do
      let(:postman) { Postman.new(:chunky => 'bacon') }

      it 'initializes jobs by json files' do
        job = double('job')
        postman.should_receive(:json_files).
          and_return ['example.json', 'example.json']
        Job.should_receive(:new).
          with('example.json', {:chunky => 'bacon'}).twice.and_return(job)
        expect(postman.send(:jobs)).to eq [job, job]
      end
    end

    describe '#json_files' do
      it 'returns a list of all json files within the jobdir' do
        postman.should_receive(:jobdir).and_return('jobdir')
        Dir.should_receive(:glob).with('jobdir/*.JSON', File::FNM_CASEFOLD).
          and_return('some files')
        expect(postman.send(:json_files)).to eq 'some files'
      end
    end

    describe '#jobdir' do
      let(:postman) { Postman.new(:jobdir => '/chunky') }

      it 'returns the jobdir from config' do
        expect(postman.send(:jobdir)).to eq '/chunky'
      end
    end
  end
end
